diff pthread.c @ 1822:7366bb5c363f libavcodec

w32threads by (Gildas Bazin <gbazin at altern dot org>)
author michael
date Thu, 19 Feb 2004 20:29:26 +0000
parents 95612d423fde
children 00a6bfc81010
line wrap: on
line diff
--- a/pthread.c	Thu Feb 19 00:30:33 2004 +0000
+++ b/pthread.c	Thu Feb 19 20:29:26 2004 +0000
@@ -54,10 +54,10 @@
 }
 
 /**
  * free what has been allocated by avcodec_pthread_init().
  * must be called after decoding has finished, especially dont call while avcodec_pthread_execute() is running
  */
-void avcodec_pthread_free(AVCodecContext *s){
+void avcodec_thread_free(AVCodecContext *s){
     ThreadContext *c= s->thread_opaque;
     int i;
 
@@ -77,7 +77,7 @@
     av_freep(&s->thread_opaque);
 }
 
-int avcodec_pthread_execute(AVCodecContext *s, int (*func)(AVCodecContext *c2, void *arg2),void **arg, int *ret, int count){
+int avcodec_thread_execute(AVCodecContext *s, int (*func)(AVCodecContext *c2, void *arg2),void **arg, int *ret, int count){
     ThreadContext *c= s->thread_opaque;
     int i, val;
     
@@ -107,7 +107,7 @@
     return 0;
 }
 
-int avcodec_pthread_init(AVCodecContext *s, int thread_count){
+int avcodec_thread_init(AVCodecContext *s, int thread_count){
     int i;
     ThreadContext *c;
 
@@ -130,10 +130,10 @@
     }
 //printf("init done\n"); fflush(stdout);
     
-    s->execute= avcodec_pthread_execute;
+    s->execute= avcodec_thread_execute;
 
     return 0;
 fail:
-    avcodec_pthread_free(s);
+    avcodec_thread_free(s);
     return -1;
 }
@@ -54,10 +54,10 @@
 
 /**
- * free what has been allocated by avcodec_pthread_init().
- * must be called after decoding has finished, especially dont call while avcodec_pthread_execute() is running
+ * free what has been allocated by avcodec_thread_init().
+ * must be called after decoding has finished, especially dont call while avcodec_thread_execute() is running
  */